Installation
============

Dependencies
------------

Requirements:

    * Python >=3.2
    * `PyQt5`_ >=5.5 or `PySide2`_ >=5.11
    * `QtPy`_ >= 1.3

Optional Python modules:

    * `h5py`_ (HDF5 files I/O)
    * `cx_Freeze`_ or `py2exe`_ (application deployment on Windows platforms)

.. _PyQt5: https://pypi.python.org/pypi/PyQt5
.. _PySide2: https://pypi.org/project/PySide2
.. _qtpy: https://pypi.org/project/QtPy/
.. _h5py: https://pypi.python.org/pypi/h5py
.. _cx_Freeze: https://pypi.python.org/pypi/cx_Freeze
.. _py2exe: https://pypi.python.org/pypi/py2exe

Other optional modules for developers:

    * gettext (text translation support)

Installation
------------

From the source package:

    `python setup.py install`

Help and support
----------------

External resources:

    * Bug reports and feature requests: `GitHub`_
    * Help, support and discussions around the project: `GoogleGroup`_

.. _GitHub: https://github.com/PierreRaybaut/guidata
.. _GoogleGroup: http://groups.google.fr/group/guidata_guiqwt
